@@ -7,12 +7,16 @@
 //! custom bundles can be crafted, simulated and submitted.
 mod bundle;
 pub use bundle::{
-    BundleHash, BundleRequest, BundleTransaction, SimulatedBundle, SimulatedTransaction,
+    BundleHash, BundleRequest, BundleStats, BundleTransaction, SimulatedBundle,
+    SimulatedTransaction,
 };
 
 mod pending_bundle;
 pub use pending_bundle::{PendingBundle, PendingBundleError};
 
+mod user;
+pub use user::UserStats;
+
 mod middleware;
 pub use middleware::{FlashbotsMiddleware, FlashbotsMiddlewareError};
 
